@@ -11,7 +11,7 @@ class Clock(Behaviour):
 
         #convert_to(seconds / tau, seconds)
 
-        neuron_or_network.clock_step_size = float(convert_to(eval(self.get_init_attr('step', '1*ms')), seconds)/second) #in ms (*ms)
+        neuron_or_network.clock_step_size = float(convert_to(eval(self.parameter('step', '1*ms')), seconds)/second) #in ms (*ms)
         self.clock_step_size=neuron_or_network.clock_step_size
         print(neuron_or_network.clock_step_size)
         neuron_or_network.t = 0.0
